"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable-next-line:no-var-requires
var plantuml = require("node-plantuml"); // there are no type definitions for this module :-(
var fs = require("fs");
var path = require("path");
/**
 * Generates local image files.
 */
var ImageGenerator = /** @class */ (function () {
    function ImageGenerator() {
        /** Prefix used for every image file. */
        this.fileNamePrefix = "umlClassDiagram-";
        /** Number of generated image files. */
        this.numberOfGeneratedImages = 0;
    }
    /**
     * Sets the output directory.
     * @param outputDirectory The path to the folder into which the files are generated.
     */
    ImageGenerator.prototype.setOutputDirectory = function (outputDirectory) {
        this.outputDirectory = outputDirectory;
    };
    /**
     * Writes a class diagram as a local image to the disc.
     * @param pageFilename The filename of the generated TypeDoc page.
     * @param encodedPlantUml The encoded PlantUML code for the diagram.
     * @param imageFormat The format of the image to generate. (eg.: "png" or "svg")
     * @returns The relative path to the generated image file.
     */
    ImageGenerator.prototype.writeImage = function (pageFilename, encodedPlantUml, imageFormat) {
        // setup plantuml encoder and decoder
        var decode = plantuml.decode(encodedPlantUml);
        var gen = plantuml.generate({ format: imageFormat });
        // get image filename
        var filename = this.fileNamePrefix + ++this.numberOfGeneratedImages + "." + imageFormat;
        var imagePath = path.join(this.outputDirectory, filename);
        // decode and save png to assets directory
        decode.out.pipe(gen.in);
        gen.out.pipe(fs.createWriteStream(imagePath));
        // get relative path filename
        var currentDirectory = path.dirname(pageFilename);
        // return the relative path
        return path.relative(currentDirectory, imagePath);
    };
    return ImageGenerator;
}());
exports.ImageGenerator = ImageGenerator;
