"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var page_section_finder_1 = require("./page_section_finder");
/**
 * Helper class for modifying TypeDoc page content.
 */
var PageProcessor = /** @class */ (function () {
    /**
     * Creates a new PageProcessor with the content of the page.
     * @param content The content of the page.
     */
    function PageProcessor(content) {
        this._content = content !== null && content !== void 0 ? content : "";
    }
    Object.defineProperty(PageProcessor.prototype, "content", {
        /**
         * Returns the current content of the page.
         * @returns The current content of the page.
         */
        get: function () {
            return this._content;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Inserts new content above a given section.
     * @param section The section above which the content should be inserted.
     * @param newContent The content to insert.
     */
    PageProcessor.prototype.insertAboveSection = function (section, newContent) {
        var sectionLocation = page_section_finder_1.PageSectionFinder.getSectionLocationInContent(this._content, section);
        if (sectionLocation.startIndex !== sectionLocation.endIndex) {
            this._content =
                this._content.substring(0, sectionLocation.startIndex) +
                    newContent +
                    this._content.substring(sectionLocation.startIndex);
        }
    };
    /**
     * Inserts new content below a given section.
     * @param section The section below which the content should be inserted.
     * @param newContent The content to insert.
     */
    PageProcessor.prototype.insertBelowSection = function (section, newContent) {
        var sectionLocation = page_section_finder_1.PageSectionFinder.getSectionLocationInContent(this._content, section);
        if (sectionLocation.startIndex !== sectionLocation.endIndex) {
            this._content =
                this._content.substring(0, sectionLocation.endIndex) +
                    newContent +
                    this._content.substring(sectionLocation.endIndex);
        }
    };
    return PageProcessor;
}());
exports.PageProcessor = PageProcessor;
